@@ -1,5 +1,6 @@
 test.regress <- function(network, likelihood, link, t1=NULL, t2=NULL) {
   n.trt <- nrow(network$treatments)
+  devianceNames <- c("Dbar", "pD", "DIC", "data points", "dev.ab", "dev.re", "fit.ab", "fit.re")
 
   # consistency model, random effects
   model <- mtc.model(network, likelihood=likelihood, link=link)
@@ -10,7 +11,7 @@ test.regress <- function(network, likelihood, link, t1=NULL, t2=NULL) {
   expect_true("sd.d" %in% rownames(s$summaries$quantiles))
   summary(relative.effect(result, t1=network$treatments$id[2]))
   expect_equal(dim(rank.probability(result)), c(n.trt, n.trt))
-  expect_equal(names(result$deviance), c("Dbar", "pD", "DIC", "dev.ab", "dev.re", "fit.ab", "fit.re"))
+  expect_equal(names(result$deviance), devianceNames)
   expect_true(!all(is.na(unlist(result$deviance[c("Dbar", "pD", "DIC")]))))
 
   # consistency model, fixed effect
@@ -22,7 +23,7 @@ test.regress <- function(network, likelihood, link, t1=NULL, t2=NULL) {
   expect_false("sd.d" %in% rownames(s$summaries$quantiles))
   summary(relative.effect(result, t1=network$treatments$id[2]))
   expect_equal(dim(rank.probability(result)), c(n.trt, n.trt))
-  expect_equal(names(result$deviance), c("Dbar", "pD", "DIC", "dev.ab", "dev.re", "fit.ab", "fit.re"))
+  expect_equal(names(result$deviance), devianceNames)
   expect_true(!all(is.na(unlist(result$deviance[c("Dbar", "pD", "DIC")]))))
 
   if (!is.null(t1) && !is.null(t2)) {
@@ -37,7 +38,7 @@ test.regress <- function(network, likelihood, link, t1=NULL, t2=NULL) {
     expect_true("d.indirect" %in% rownames(s$summaries$quantiles))
     expect_error(relative.effect(result, t1="C"))
     expect_error(rank.probability(result))
-    expect_equal(names(result$deviance), c("Dbar", "pD", "DIC", "dev.ab", "dev.re", "fit.ab", "fit.re"))
+    expect_equal(names(result$deviance), devianceNames)
     expect_true(!all(is.na(unlist(result$deviance[c("Dbar", "pD", "DIC")]))))
 
     # node-splitting, fixed effect
@@ -48,7 +49,7 @@ test.regress <- function(network, likelihood, link, t1=NULL, t2=NULL) {
     expect_false("sd.d" %in% rownames(s$summaries$quantiles))
     expect_true("d.direct" %in% rownames(s$summaries$quantiles))
     expect_true("d.indirect" %in% rownames(s$summaries$quantiles))
-    expect_equal(names(result$deviance), c("Dbar", "pD", "DIC", "dev.ab", "dev.re", "fit.ab", "fit.re"))
+    expect_equal(names(result$deviance), devianceNames)
     expect_true(!all(is.na(unlist(result$deviance[c("Dbar", "pD", "DIC")]))))
   }
 
@@ -57,7 +58,7 @@ test.regress <- function(network, likelihood, link, t1=NULL, t2=NULL) {
   capture.output(result <- mtc.run(model, n.adapt=100, n.iter=500))
   plot(result)
   s <- summary(result)
-  expect_equal(names(result$deviance), c("Dbar", "pD", "DIC", "dev.ab", "dev.re", "fit.ab", "fit.re"))
+  expect_equal(names(result$deviance), devianceNames)
   expect_true(!all(is.na(unlist(result$deviance[c("Dbar", "pD", "DIC")]))))
 
   # ume, fixed effect
@@ -65,7 +66,7 @@ test.regress <- function(network, likelihood, link, t1=NULL, t2=NULL) {
   capture.output(result <- mtc.run(model, n.adapt=100, n.iter=500))
   plot(result)
   s <- summary(result)
-  expect_equal(names(result$deviance), c("Dbar", "pD", "DIC", "dev.ab", "dev.re", "fit.ab", "fit.re"))
+  expect_equal(names(result$deviance), devianceNames)
   expect_true(!all(is.na(unlist(result$deviance[c("Dbar", "pD", "DIC")]))))
 
   # anohe, random effects
@@ -74,7 +75,7 @@ test.regress <- function(network, likelihood, link, t1=NULL, t2=NULL) {
   anohe.s <- summary(anohe)
   plot(anohe.s)
   capture.output(print(anohe.s))
-  expect_equal(names(result$deviance), c("Dbar", "pD", "DIC", "dev.ab", "dev.re", "fit.ab", "fit.re"))
+  expect_equal(names(result$deviance), devianceNames)
   expect_true(!all(is.na(unlist(result$deviance[c("Dbar", "pD", "DIC")]))))
 
   # anohe, fixed effect
@@ -83,6 +84,6 @@ test.regress <- function(network, likelihood, link, t1=NULL, t2=NULL) {
   anohe.s <- summary(anohe)
   plot(anohe.s)
   capture.output(print(anohe.s))
-  expect_equal(names(result$deviance), c("Dbar", "pD", "DIC", "dev.ab", "dev.re", "fit.ab", "fit.re"))
+  expect_equal(names(result$deviance), devianceNames)
   expect_true(!all(is.na(unlist(result$deviance[c("Dbar", "pD", "DIC")]))))
 }
